"""LMU metapackage (should not be imported directly)."""

import sys

from keras_lmu.layers import LMU, LMUCell, LMUFFT

print(
    "'lmu' is a metapackage that should not be imported directly. You might be "
    "intending to `import keras_lmu` (which used to be generically referred to as "
    "'lmu'). For now this will have the effect of importing 'keras_lmu', but this will "
    "not work in the future so you should update your imports.",
    file=sys.stderr,
)



"""LMU version information.

We use semantic versioning (see http://semver.org/).
and conform to PEP440 (see https://www.python.org/dev/peps/pep-0440/).
'.devN' will be added to the version unless the code base represents
a release version. Release versions are git tagged with the version.
"""

name = "lmu"
version_info = (0, 3, 0)  # (major, minor, patch)
dev = None

version = (
    f"{'.'.join(str(v) for v in version_info)}{f'.dev{dev}' if dev is not None else ''}"
)



from importlib import reload

import keras_lmu
import lmu


def test_import_fallback(capsys):
    reload(lmu)

    assert (
        "'lmu' is a metapackage that should not be imported" in capsys.readouterr().err
    )

    assert lmu.LMU is keras_lmu.LMU
    assert lmu.LMUCell is keras_lmu.LMUCell
    assert lmu.LMUFFT is keras_lmu.LMUFFT



#!/usr/bin/env python

# Automatically generated by nengo-bones, do not edit this file directly

import io
import os
import runpy

try:
    from setuptools import find_packages, setup
except ImportError:
    raise ImportError(
        "'setuptools' is required but not installed. To install it, "
        "follow the instructions at "
        "https://pip.pypa.io/en/stable/installing/#installing-with-get-pip-py"
    )


def read(*filenames, **kwargs):
    encoding = kwargs.get("encoding", "utf-8")
    sep = kwargs.get("sep", "\n")
    buf = []
    for filename in filenames:
        with io.open(filename, encoding=encoding) as f:
            buf.append(f.read())
    return sep.join(buf)


root = os.path.dirname(os.path.realpath(__file__))
version = runpy.run_path(os.path.join(root, "lmu", "version.py"))["version"]

install_req = [
    "keras-lmu>=0.3.0",
]
docs_req = []
optional_req = []
tests_req = [
    "pytest>=6.1.0",
]

setup(
    name="lmu",
    version=version,
    author="Applied Brain Research",
    author_email="info@appliedbrainresearch.com",
    packages=find_packages(),
    url="https://github.com/nengo/lmu",
    include_package_data=False,
    license="Free for non-commercial use",
    description="LMU metapackage for installing various LMU implementations",
    long_description=read("README.rst", "CHANGES.rst"),
    zip_safe=False,
    install_requires=install_req,
    extras_require={
        "all": docs_req + optional_req + tests_req,
        "docs": docs_req,
        "optional": optional_req,
        "tests": tests_req,
    },
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Science/Research",
        "License :: Free for non-commercial use",
        "Operating System :: OS Independent",
        "Programming Language :: Python ",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Scientific/Engineering ",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
)
